ui

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 17, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package ui contains Model, which represents main window of TUI

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Model

type Model struct {
	// contains filtered or unexported fields
}

func New

func New() Model

func (Model) Init

func (m Model) Init() tea.Cmd

func (*Model) Resize

func (m *Model) Resize(width, height int)

func (Model) Update

func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (Model) View

func (m Model) View() string

Directories

Path Synopsis
components
label
Package label provides simple model with text, which should be shown to user
Package label provides simple model with text, which should be shown to user
overlay
Package overlay provides simple overlay windows
Package overlay provides simple overlay windows
Package connections provides tabbed tables with main iformation about variable connections
Package connections provides tabbed tables with main iformation about variable connections
Package controls provides simple public controls of main ui
Package controls provides simple public controls of main ui
Package styles contains common styles for whole app
Package styles contains common styles for whole app

Jump to